@@ -1,6 +1,6 @@
 """ESPNCricInfo player model."""
 
-# pylint: disable=too-many-arguments,too-many-statements,too-many-locals,duplicate-code
+# pylint: disable=too-many-arguments,too-many-statements,too-many-locals,duplicate-code,too-many-positional-arguments
 import datetime
 import statistics
 import urllib.parse
@@ -598,4 +598,378 @@ def create_espncricinfo_player_model(
         shots_foot_errors_percentage=None,
         shots_unknown_percentage=None,
         points_won_percentage=None,
+        centre_clearances=None,
+        disposal_efficiency=None,
+        tackles_inside_50=None,
+        total_possessions=None,
+        score_involvements=None,
+        goal_accuracy=None,
+        stoppage_clearances=None,
+        uncontested_marks=None,
+        accurate_crosses=None,
+        accurate_long_balls=None,
+        accurate_passes=None,
+        accurate_through_balls=None,
+        cross_percentage=None,
+        free_kick_goals=None,
+        free_kick_percentage=None,
+        free_kick_shots=None,
+        game_winning_assists=None,
+        headed_goals=None,
+        inaccurate_crosses=None,
+        inaccurate_long_balls=None,
+        inaccurate_passes=None,
+        inaccurate_through_balls=None,
+        left_footed_shots=None,
+        long_ball_percentage=None,
+        penalty_kick_goals=None,
+        penalty_kick_percentage=None,
+        penalty_kicks_missed=None,
+        possession_percentage=None,
+        possession_time=None,
+        right_footed_shots=None,
+        shoot_out_goals=None,
+        shoot_out_misses=None,
+        shoot_out_percentage=None,
+        shot_assists=None,
+        shot_percentage=None,
+        shots_headed=None,
+        shots_off_target=None,
+        shots_on_post=None,
+        through_ball_percentage=None,
+        long_balls=None,
+        total_passes=None,
+        average_rating_from_editor=None,
+        average_rating_from_user=None,
+        did_not_play=None,
+        draws=None,
+        goal_difference=None,
+        losses=None,
+        lost_corners=None,
+        minutes=None,
+        pass_percentage=None,
+        starts=None,
+        sub_ins=None,
+        sub_outs=None,
+        suspensions=None,
+        time_ended=None,
+        time_started=None,
+        win_percentage=None,
+        wins=None,
+        won_corners=None,
+        clean_sheet=None,
+        crosses_caught=None,
+        goals_conceded=None,
+        partial_clean_sheet=None,
+        penalty_kick_conceded=None,
+        penalty_kick_save_percentage=None,
+        penalty_kicks_faced=None,
+        penalty_kicks_saved=None,
+        punches=None,
+        shoot_out_kicks_faced=None,
+        shoot_out_kicks_saved=None,
+        shoot_out_save_percentage=None,
+        shots_faced=None,
+        smothers=None,
+        unclaimed_crosses=None,
+        effective_clearances=None,
+        effective_tackles=None,
+        ineffective_tackles=None,
+        tackle_percentage=None,
+        appearances=None,
+        average_rating_from_correspondent=None,
+        average_rating_from_data_feed=None,
+        games_played=None,
+        team_games_played=None,
+        hit_by_pitch=None,
+        rbis=None,
+        sac_hits=None,
+        stolen_bases=None,
+        walks=None,
+        catcher_interference=None,
+        gidps=None,
+        sac_flies=None,
+        grand_slam_home_runs=None,
+        runners_left_on_base=None,
+        triples=None,
+        game_winning_rbis=None,
+        intentional_walks=None,
+        doubles=None,
+        caught_stealing=None,
+        games_started=None,
+        pinch_at_bats=None,
+        pinch_hits=None,
+        player_rating=None,
+        is_qualified=None,
+        is_qualified_steals=None,
+        total_bases=None,
+        projected_home_runs=None,
+        extra_base_hits=None,
+        runs_created=None,
+        batting_average=None,
+        pinch_average=None,
+        slug_average=None,
+        secondary_average=None,
+        on_base_percentage=None,
+        ground_to_fly_ratio=None,
+        runs_created_per_27_outs=None,
+        batter_rating=None,
+        at_bats_per_home_run=None,
+        stolen_base_percentage=None,
+        pitches_per_plate_appearance=None,
+        isolated_power=None,
+        walk_to_strikeout_ratio=None,
+        walks_per_plate_appearance=None,
+        secondary_average_minus_batting_average=None,
+        runs_produced=None,
+        runs_ratio=None,
+        patience_ratio=None,
+        balls_in_play_average=None,
+        mlb_rating=None,
+        offensive_wins_above_replacement=None,
+        wins_above_replacement=None,
+        batters_hit=None,
+        sacrifice_bunts=None,
+        save_opportunities=None,
+        finishes=None,
+        balks=None,
+        holds=None,
+        complete_games=None,
+        perfect_games=None,
+        wild_pitches=None,
+        third_innings=None,
+        team_earned_runs=None,
+        pickoff_attempts=None,
+        run_support=None,
+        pitches_as_starter=None,
+        average_game_score=None,
+        quality_starts=None,
+        inherited_runners_scored=None,
+        opponent_total_bases=None,
+        is_qualified_saves=None,
+        full_innings=None,
+        part_innings=None,
+        blown_saves=None,
+        innings=None,
+        whip=None,
+        caught_stealing_percentage=None,
+        pitches_per_start=None,
+        pitches_per_inning=None,
+        run_support_average=None,
+        opponent_average=None,
+        opponent_slug_average=None,
+        opponent_on_base_percentage=None,
+        opponent_ops=None,
+        strikeouts_per_nine_innings=None,
+        strikeout_to_walk_ratio=None,
+        tough_losses=None,
+        cheap_wins=None,
+        save_opportunities_per_win=None,
+        pitch_count=None,
+        strike_pitch_ratio=None,
+        double_plays=None,
+        opportunities=None,
+        passed_balls=None,
+        outfield_assists=None,
+        pickoffs=None,
+        outs_on_field=None,
+        triple_plays=None,
+        balls_in_zone=None,
+        extra_bases=None,
+        outs_made=None,
+        catcher_third_innings_played=None,
+        catcher_caught_stealing=None,
+        catcher_stolen_bases_allowed=None,
+        catcher_earned_runs=None,
+        is_qualified_catcher=None,
+        is_qualified_pitcher=None,
+        successful_chances=None,
+        total_chances=None,
+        full_innings_played=None,
+        part_innings_played=None,
+        fielding_percentage=None,
+        range_factor=None,
+        zone_rating=None,
+        catcher_caught_stealing_percentage=None,
+        catcher_era=None,
+        def_warbr=None,
+        average_three_point_field_goals_attempted=None,
+        average_free_throws_made=None,
+        average_free_throws_attempted=None,
+        average_points=None,
+        average_offensive_rebounds=None,
+        average_assists=None,
+        average_turnovers=None,
+        estimated_possessions=None,
+        average_estimated_possessions=None,
+        points_per_estimated_possessions=None,
+        average_team_turnovers=None,
+        average_total_turnovers=None,
+        three_point_field_goal_percentage=None,
+        two_point_field_goals_made=None,
+        two_point_field_goals_attempted=None,
+        average_two_point_field_goals_made=None,
+        average_two_point_field_goals_attempted=None,
+        two_point_field_goal_percentage=None,
+        shooting_efficiency=None,
+        scoring_efficiency=None,
+        average_48_field_goals_made=None,
+        average_48_field_goals_attempted=None,
+        average_48_three_point_field_goals_made=None,
+        average_48_three_point_field_goals_attempted=None,
+        average_48_free_throws_made=None,
+        average_48_free_throws_attempted=None,
+        average_48_points=None,
+        average_48_offensive_rebounds=None,
+        average_48_assists=None,
+        average_48_turnovers=None,
+        p40=None,
+        a40=None,
+        average_rebounds=None,
+        average_fouls=None,
+        average_flagrant_fouls=None,
+        average_technical_fouls=None,
+        average_ejections=None,
+        average_disqualifications=None,
+        assist_turnover_ratio=None,
+        steal_foul_ratio=None,
+        block_foul_ratio=None,
+        average_team_rebounds=None,
+        total_technical_fouls=None,
+        team_assist_turnover_ratio=None,
+        steal_turnover_ratio=None,
+        average_48_rebounds=None,
+        average_48_fouls=None,
+        average_48_flagrant_fouls=None,
+        average_48_technical_fouls=None,
+        average_48_ejections=None,
+        average_48_disqualifications=None,
+        r40=None,
+        double_double=None,
+        triple_double=None,
+        free_throws_made=None,
+        three_point_percentage=None,
+        three_point_field_goals_made=None,
+        total_turnovers=None,
+        points_in_paint=None,
+        brick_index=None,
+        average_field_goals_made=None,
+        average_field_goals_attempted=None,
+        average_three_point_field_goals_made=None,
+        average_defensive_rebounds=None,
+        average_blocks=None,
+        average_steals=None,
+        average_48_defensive_rebounds=None,
+        average_48_blocks=None,
+        average_48_steals=None,
+        largest_lead=None,
+        disqualifications=None,
+        flagrant_fouls=None,
+        fouls=None,
+        ejections=None,
+        technical_fouls=None,
+        average_minutes=None,
+        nba_rating=None,
+        plus_minus=None,
+        even_strength_time_on_ice=None,
+        shifts_per_game=None,
+        production=None,
+        shot_differential=None,
+        goal_differential=None,
+        pim_differential=None,
+        rating=None,
+        average_goals=None,
+        ytd_goals=None,
+        shots_in_first_period=None,
+        shots_in_second_period=None,
+        shots_in_third_period=None,
+        shots_overtime=None,
+        average_shots=None,
+        points_per_game=None,
+        power_play_opportunities=None,
+        power_play_percentage=None,
+        shootout_attempts=None,
+        shootout_shot_percentage=None,
+        empty_net_goals_for=None,
+        shutouts_against=None,
+        total_face_offs=None,
+        average_goals_against=None,
+        average_shots_against=None,
+        penalty_kill_percentage=None,
+        power_play_goals_against=None,
+        short_handed_goals_against=None,
+        shootout_saves=None,
+        shootout_shots_against=None,
+        times_short_handed=None,
+        empty_net_goals_against=None,
+        overtime_losses=None,
+        shots_missed=None,
+        minor_penalties=None,
+        match_penalties=None,
+        misconducts=None,
+        game_misconducts=None,
+        boarding_penalties=None,
+        unsportsmanlike_penalties=None,
+        fighting_penalties=None,
+        average_fights=None,
+        time_between_fights=None,
+        instigator_penalties=None,
+        charging_penalties=None,
+        hooking_penalties=None,
+        tripping_penalties=None,
+        roughing_penalties=None,
+        holding_penalties=None,
+        interference_penalties=None,
+        slashing_penalties=None,
+        high_sticking_penalties=None,
+        cross_checking_penalties=None,
+        stick_holding_penalties=None,
+        goalie_interference_penalties=None,
+        elbowing_penalties=None,
+        diving_penalties=None,
+        takeaways=None,
+        even_strength_saves=None,
+        power_play_saves=None,
+        short_handed_saves=None,
+        games=None,
+        game_started=None,
+        ties=None,
+        time_on_ice_per_game=None,
+        power_play_time_on_ice=None,
+        short_handed_time_on_ice=None,
+        faceoffs_won=None,
+        faceoffs_lost=None,
+        faceoff_percentage=None,
+        unassisted_goals=None,
+        game_tying_goals=None,
+        giveaways=None,
+        penalties=None,
+        penalty_minutes=None,
+        penalty_minutes_against=None,
+        major_penalties=None,
+        net_passing_yards_per_game=None,
+        net_yards_per_game=None,
+        passing_yards_per_game=None,
+        total_points_per_game=None,
+        yards_from_scrimmage_per_game=None,
+        yards_per_game=None,
+        espn_rb_rating=None,
+        rushing_yards_per_game=None,
+        receiving_yards_per_game=None,
+        two_point_returns=None,
+        field_goal_attempts=None,
+        special_team_fumble_return_yards=None,
+        kick_extra_points=None,
+        kick_extra_points_made=None,
+        attempts_in_box=None,
+        second_assists=None,
+        qbr=None,
+        attempts_out_box=None,
+        adjusted_qbr=None,
+        turnover_points=None,
+        fantasy_rating=None,
+        team_turnovers=None,
+        second_chance_points=None,
+        fast_break_points=None,
+        team_rebounds=None,
     )
